Documentation
¶
Overview ¶
Package initialize installs Aruo's managed engineering contract into an existing repository.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AugmentPlan ¶
func AugmentPlan(plan templateengine.Plan) (templateengine.Plan, error)
AugmentPlan merges the managed Aruo contract into a rendered creation plan. The caller can then commit application files and governance files through one atomic writer operation.
Types ¶
type FileChange ¶
FileChange describes one proposed managed file.
type Plan ¶
type Plan struct {
Repository string `json:"repository"`
Stack Stack `json:"stack"`
Changes []FileChange `json:"changes"`
Conflicts []string `json:"conflicts,omitempty"`
// contains filtered or unexported fields
}
Plan is a side-effect-free initialization proposal.
type Request ¶
type Request struct {
Target string
}
Request describes one repository adoption operation.
type Result ¶
type Result struct {
Repository string `json:"repository"`
Stack Stack `json:"stack"`
Changes []FileChange `json:"changes"`
DryRun bool `json:"dryRun"`
}
Result describes a completed or dry-run initialization.
Click to show internal directories.
Click to hide internal directories.